==> fmrdsnotify_0.7.2.tar.gz: fmrdsnotify-0.7.2/src/CRTCom.h <==
/**********************************************************************************************
    Copyright (C) 2009 Fabrice Crohas fcrohas@gmail.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

**********************************************************************************************/
#ifndef CRTCOM_H
#define CRTCOM_H

#include "IRdsText.h"
#include <QtDBus>


class CRTCom : public IRdsText
{
    Q_OBJECT;
    public:
        CRTCom(QObject * parent);
        virtual ~CRTCom();

        static CRTCom& self(){return *m_self;}

        /// Displayed text format
        void    setFormat(QString value);
	QString getFormat();
	// End time
        void    setTimeout(int value);
	int getTimeout();
	// state plug on or off
        void    setEnable(bool value);
	bool getEnable();
        bool getState();
	// connect plug
	void setConnect(int value);

        signals:
        /// emitted when ever the new text is changed
        void sigChanged(QString,int);

    private:
	// Send text to writer
	void sendText(QString text);

        static CRTCom * m_self;

        /// the format of rds displayed data
        QString format;
	// Formated text 
        QString callText;
	// tiimeout of displayed text
	int timeout;
	// Pluig status
	bool state;
        // Tx connect state
        bool connect;

    private slots:
	void slotComingChanged(QDBusObjectPath objectPath, QString caller);
	void slotCallStatus(uint state, uint ukn1, uint ukn2);
};
#endif                           //CRTCOM

==> fmrdsnotify_0.8.1.tar.gz: fmrdsnotify-0.8.1/src/CRTCom.h <==
/**********************************************************************************************
    Copyright (C) 2009 Fabrice Crohas fcrohas@gmail.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

**********************************************************************************************/
#ifndef CRTCOM_H
#define CRTCOM_H

#include "IRdsText.h"
#include <QtDBus>


class CRTCom : public IRdsText
{
    Q_OBJECT;
    public:
        CRTCom(QObject * parent);
        virtual ~CRTCom();

        static CRTCom& self(){return *m_self;}

        /// Displayed text format
        void    setFormat(QString value);
	QString getFormat();
	// End time
        void    setTimeout(int value);
	int getTimeout();
	// state plug on or off
        void    setEnable(bool value);
	bool getEnable();
        bool getState();
	// connect plug
	void setConnect(int value);

        signals:
        /// emitted when ever the new text is changed
        //void sigChanged(QString,int);

    private:
	// Send text to writer
	void sendText(QString text);

        static CRTCom * m_self;

        /// the format of rds displayed data
        QString format;
	// Formated text 
        QString callText;
	// tiimeout of displayed text
	int timeout;
	// Pluig status
	bool state;
        // Tx connect state
        bool connect;

    private slots:
	void slotComingChanged(QDBusObjectPath objectPath, QString caller);
	void slotCallStatus(uint state, uint ukn1, uint ukn2);
};
#endif                           //CRTCOM
